@@ -6,7 +6,7 @@ from crabnet.train_crabnet import get_model
 
 def test_crabnet():
     train_df, val_df = data(elasticity, dummy=True)
-    mdl = get_model(train_df=train_df, val_df=val_df)
+    mdl = get_model(train_df=train_df, val_df=val_df, verbose=True)
 
     train_true, train_pred, formulas, train_sigma = mdl.predict(val_df)
     return train_true, train_pred, formulas, train_sigma
